@@ -27,6 +27,18 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: codecs.h,v $
+ * Revision 1.7  2010/09/19 05:43:39  shorne
+ * Added SetSupportedFormats
+ *
+ * Revision 1.6  2010/06/06 14:53:26  shorne
+ * Added AVSync support, Aspect Ratio management, flow Control, Video 90k clock, fixes for wideband codecs and generic audio capabilities
+ *
+ * Revision 1.5  2010/05/02 22:43:05  shorne
+ * Added RTP Information structure to be able to support A/V sync
+ *
+ * Revision 1.4  2009/07/09 15:11:12  shorne
+ * Simplfied and standardised compiler directives
+ *
  * Revision 1.3  2008/05/23 11:19:05  willamowius
  * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
  *
@@ -338,7 +350,7 @@
 #include <rtp.h>
 #include <channels.h>
 #include "openh323buildopts.h"
-
+#include <ptlib/video.h>
 
 /* The following classes have forward references to avoid including the VERY
    large header files for H225 and H245. If an application requires access
@@ -349,8 +361,6 @@ class H245_MiscellaneousCommand_type;
 class H245_MiscellaneousIndication_type;
 class H323Connection;
 
-
-
 ///////////////////////////////////////////////////////////////////////////////
 
 /**This class embodies the implementation of a specific codec instance
@@ -360,17 +370,32 @@ class H323Connection;
    An application may create a descendent off this class and override
    functions as required for descibing a codec.
  */
-class PAec;
 class H323Codec : public PObject
 {
   PCLASSINFO(H323Codec, PObject);
 
   public:
+
     enum Direction {
       Encoder,
       Decoder
     };
 
+	struct H323_RTPInformation
+	{
+		int                   m_sessionID;
+        int                   m_frameLost;
+        PTime                 m_sendTime;
+        PTime                 m_recvTime;
+		const RTP_DataFrame * m_frame;
+	};
+
+    struct AVSync
+    {
+        DWORD m_rtpTimeStamp;
+        PTime m_realTimeStamp;
+    };
+
     H323Codec(
       const OpalMediaFormat & mediaFormat, ///< Media format for codec
       Direction direction       ///< Direction in which this instance runs
@@ -521,7 +546,8 @@ class H323Codec : public PObject
       */
     PBoolean WriteRaw(
       void * data,
-      PINDEX length
+      PINDEX length,
+	  void * mark
     );
 
     /**Attach the logical channel, for use by the codec.
@@ -574,6 +600,15 @@ class H323Codec : public PObject
     */
     virtual PBoolean SetRawDataHeld(PBoolean hold );
 
+   /**On Receive sender report.
+        Use this for AV Synchronisation
+    */
+    virtual PBoolean OnRxSenderReport(DWORD rtpTimeStamp, const PTime & realTimeStamp);
+
+   /**Calculate the remote send time
+    */
+    virtual PTime CalculateRTPSendTime(DWORD timeStamp, unsigned rate) const;
+
   protected:
     Direction direction;
     OpalMediaFormat mediaFormat;
@@ -586,11 +621,14 @@ class H323Codec : public PObject
 
     PINDEX     lastSequenceNumber;  // Detects lost RTP packets in the video codec.
 
+	H323_RTPInformation  rtpInformation;
+    AVSync  rtpSync;
+
     PLIST(FilterList, PNotifier);
     FilterList filters;
 };
 
-#ifndef NO_H323_AUDIO_CODECS
+#ifdef H323_AUDIO_CODECS
 
 
 /**This class defines a codec class that will use the standard platform PCM
@@ -642,6 +680,10 @@ class H323AudioCodec : public H323Codec
       */
     virtual unsigned GetFrameRate() const;
 
+    /**Get the frame time.
+      */
+    virtual unsigned GetFrameTime() const;
+
     enum SilenceDetectionMode {
       NoSilenceDetection,
       FixedSilenceDetection,
@@ -923,7 +965,7 @@ class H323StreamedAudioCodec : public H323FramedAudioCodec
 #endif // NO_H323_AUDIO_CODECS
 
 
-#ifndef NO_H323_VIDEO
+#ifdef H323_VIDEO
 
 /**This class defines a codec class that will use the standard platform image
    output device.
@@ -1054,6 +1096,14 @@ class H323VideoCodec : public H323Codec
      */ 
     virtual unsigned GetHeight() const { return frameHeight; }
 
+    /** Get width of sample aspect ratio
+     */
+    virtual unsigned GetSarWidth() const { return sarWidth; }
+
+    /** Get height of sample aspect ratio
+     */
+    virtual unsigned GetSarHeight() const { return sarHeight; }
+
     /**Quality of the transmitted video. 1 is good, 31 is poor.
      */
     virtual void SetTxQualityLevel(int qlevel) {videoQuality = qlevel; }
@@ -1134,14 +1184,20 @@ class H323VideoCodec : public H323Codec
    /** 
        Returns the number of frames transmitted or received so far. 
    */
-   virtual int GetFrameNum() { return frameNum; }
+    virtual int GetFrameNum() { return frameNum; }
 
+   /**
+      Set the supported Formats the codec is to support
+    */
+    virtual void SetSupportedFormats(std::list<PVideoFrameInfo> & info);
 
   protected:
 
     int frameWidth;
     int frameHeight;
     int fillLevel;
+    int sarWidth;
+    int sarHeight;
 
     // used in h261codec.cxx
     unsigned videoBitRateControlModes;
@@ -1167,7 +1223,7 @@ class H323VideoCodec : public H323Codec
 
 #endif // NO_H323_VIDEO
 
-#ifndef NO_H323_AUDIO_CODECS
+#ifdef H323_AUDIO_CODECS
 
 ///////////////////////////////////////////////////////////////////////////////
 // The simplest codec is the G.711 PCM codec.
