@@ -27,6 +27,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: gkserver.h,v $
+ * Revision 1.3  2011/02/20 06:55:46  shorne
+ * Fixes for H.460 to allow better selection of mesasage location in PDU. Features or Generic Data. Corrected H.460.9
+ *
  * Revision 1.2  2008/05/23 11:19:17  willamowius
  * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
  *
@@ -1381,7 +1384,7 @@ class H323GatekeeperListener : public H225_RAS
     PBoolean OnReceiveLocationRequest(const H323RasPDU &, const H225_LocationRequest &);
     PBoolean OnReceiveInfoRequestResponse(const H323RasPDU &, const H225_InfoRequestResponse &);
     PBoolean OnReceiveResourcesAvailableConfirm(const H225_ResourcesAvailableConfirm &);
-    PBoolean OnSendFeatureSet(unsigned, H225_FeatureSet & features) const;
+    PBoolean OnSendFeatureSet(unsigned, H225_FeatureSet & features, PBoolean) const;
     void OnReceiveFeatureSet(unsigned, const H225_FeatureSet & features) const;
   //@}
 
@@ -1945,7 +1948,7 @@ class H323GatekeeperServer : public H323TransactionServer
     virtual PBoolean AllowDuplicateAlias(const H225_ArrayOf_AliasAddress & /*aliases*/)
     { return canHaveDuplicateAlias; }
 
-    virtual PBoolean OnSendFeatureSet(unsigned, H225_FeatureSet & features) const;
+    virtual PBoolean OnSendFeatureSet(unsigned, H225_FeatureSet & features, PBoolean) const;
     virtual void OnReceiveFeatureSet(unsigned, const H225_FeatureSet & features) const;
 
   protected:
