@@ -24,6 +24,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: h323trans.h,v $
+ * Revision 1.3  2011/05/09 07:14:03  shorne
+ * Remove redundent PTLIB Linking code
+ *
  * Revision 1.2  2008/05/23 11:19:51  willamowius
  * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
  *
@@ -264,17 +267,6 @@ class H323Transactor : public PObject
       */
     PBoolean GetCheckResponseCryptoTokens() { return checkResponseCryptoTokens; }
   //@}
-
-  protected:
-    void Construct();
-
-    unsigned GetNextSequenceNumber();
-    PBoolean SetUpCallSignalAddresses(
-      H225_ArrayOf_TransportAddress & addresses
-    );
-
-    //Background thread handler.
-    PDECLARE_NOTIFIER(PThread, H323Transactor, HandleTransactions);
 	
     class Request : public PObject
     {
@@ -317,6 +309,17 @@ class H323Transactor : public PObject
         } responseResult;
     };
 
+  protected:
+    void Construct();
+
+    unsigned GetNextSequenceNumber();
+    PBoolean SetUpCallSignalAddresses(
+      H225_ArrayOf_TransportAddress & addresses
+    );
+
+    //Background thread handler.
+    PDECLARE_NOTIFIER(PThread, H323Transactor, HandleTransactions);
+
     virtual PBoolean MakeRequest(
       Request & request
     );
@@ -367,7 +370,7 @@ class H323Transactor : public PObject
     unsigned  nextSequenceNumber;
     PMutex    nextSequenceNumberMutex;
 
-    PDictionary<POrdinalKey, Request> requests;
+    H323Dictionary<POrdinalKey, Request> requests;
     PMutex                            requestsMutex;
     Request                         * lastRequest;
 
