@@ -24,6 +24,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: h450pdu.h,v $
+ * Revision 1.3  2011/05/09 07:14:03  shorne
+ * Remove redundent PTLIB Linking code
+ *
  * Revision 1.2  2008/05/23 11:20:49  willamowius
  * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
  *
@@ -90,6 +93,7 @@
 
 
 #include "x880.h"
+#include "ptlib_extras.h"
 
 
 class H323EndPoint;
@@ -219,7 +223,7 @@ class H450xHandler : public PObject
 };
 
 PLIST(H450xHandlerList, H450xHandler);
-PDICTIONARY(H450xHandlerDict, POrdinalKey, H450xHandler);
+H323DICTIONARY(H450xHandlerDict, POrdinalKey, H450xHandler);
 
 
 class H450xDispatcher : public PObject
