@@ -27,6 +27,36 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: rtp.h,v $
+ * Revision 1.15  2011/05/09 07:35:47  shorne
+ * updates for changes in PTLIB v2.11. The replacement of PDICTIONARY with H323Dictionary. Updates for the changes in the PNatMethod Class. Alteration in PFactory::Create, Remove redundent code and change change logging
+ *
+ * Revision 1.14  2011/01/12 13:08:38  shorne
+ * H.239 Clunge for channelID=0 and set Channelid in OLCack
+ *
+ * Revision 1.13  2010/09/19 05:53:28  shorne
+ * Added NAT Support for Unidirection media channels (H.239) fix to set random timestamp rather than  zero. Fix the timestamp on the marker frame.
+ *
+ * Revision 1.12  2010/08/26 15:12:39  shorne
+ * Major H.239 upgrade. Special thx again to Marek Domaracky and Igor Pavlov
+ *
+ * Revision 1.11  2010/06/06 14:53:26  shorne
+ * Added AVSync support, Aspect Ratio management, flow Control, Video 90k clock, fixes for wideband codecs and generic audio capabilities
+ *
+ * Revision 1.10  2010/05/03 03:56:34  shorne
+ * Improved collection of sender reports including identifying session they originated from
+ *
+ * Revision 1.9  2010/04/12 21:39:54  willamowius
+ * give application access to RTP sender reports
+ *
+ * Revision 1.8  2009/11/29 23:31:05  shorne
+ * BUG FIX : completely disable H.460 support if remote does not support it.
+ *
+ * Revision 1.7  2009/07/09 15:11:12  shorne
+ * Simplfied and standardised compiler directives
+ *
+ * Revision 1.6  2009/06/28 01:41:52  shorne
+ * Replaced P_HAS_QOS with P_QOS (depreciated in PTLib)
+ *
  * Revision 1.5  2008/05/23 11:20:01  willamowius
  * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
  *
@@ -262,6 +292,8 @@
 #include <openh323buildopts.h>
 #include <ptlib/sockets.h>
 
+#include "ptlib_extras.h"
+
 class RTP_JitterBuffer;
 class PHandleAggregator;
 
@@ -273,7 +305,7 @@ class PNatMethod;
 // 
 // class to hold the QoS definitions for an RTP channel
 
-#if P_HAS_QOS
+#if P_QOS
 
 class RTP_QOS : public PObject
 {
@@ -490,52 +522,10 @@ class RTP_ControlFrame : public PBYTEArray
 };
 
 
-class RTP_Session;
-
-/**This class is the base for user data that may be attached to the RTP_session
-   allowing callbacks for statistics and progress monitoring to be passed to an
-   arbitrary object that an RTP consumer may require.
-  */
-class RTP_UserData : public PObject
-{
-  PCLASSINFO(RTP_UserData, PObject);
-
-  public:
-    /**Callback from the RTP session for transmit statistics monitoring.
-       This is called every RTP_Session::txStatisticsInterval packets on the
-       transmitter indicating that the statistics have been updated.
-
-       The default behaviour does nothing.
-      */
-    virtual void OnTxStatistics(
-      const RTP_Session & session   ///<  Session with statistics
-    ) const;
-
-    /**Callback from the RTP session for receive statistics monitoring.
-       This is called every RTP_Session::receiverReportInterval packets on the
-       receiver indicating that the statistics have been updated.
-
-       The default behaviour does nothing.
-      */
-    virtual void OnRxStatistics(
-      const RTP_Session & session   ///<  Session with statistics
-    ) const;
-
-    /**Callback from the RTP session for statistics monitoring.
-       This is called at the end of a call to indicating 
-	   that the statistics of the call.
-
-       The default behaviour does nothing.
-      */
-    virtual void OnFinalStatistics(
-      const RTP_Session & session   ///<  Session with statistics
-    ) const;
-};
-
-
 /**This class is for encpsulating the IETF Real Time Protocol interface.
  */
 class RTP_UDP;
+class RTP_UserData;
 class RTP_Session : public PObject
 {
   PCLASSINFO(RTP_Session, PObject);
@@ -615,6 +605,13 @@ class RTP_Session : public PObject
       PBoolean loop                ///<  If TRUE, loop as long as data is available, if FALSE, only process once
     ) = 0;
 
+    /**Read a data frame from the RTP channel that did not orginate
+       from the UDPSocket
+      */
+    virtual PBoolean PseudoRead(
+        int & selectStatus
+     );
+
     /**Write a data frame from the RTP channel.
       */
     virtual PBoolean WriteData(
@@ -683,6 +680,7 @@ class RTP_Session : public PObject
                                   const ReceiverReportArray & reports);
     virtual void OnRxReceiverReport(DWORD src,
                                     const ReceiverReportArray & reports);
+    virtual bool AVSyncData(SenderReport & sender);
 
     class SourceDescription : public PObject  {
         PCLASSINFO(SourceDescription, PObject);
@@ -709,6 +707,10 @@ class RTP_Session : public PObject
       */
     unsigned GetSessionID() const { return sessionID; }
 
+    /**Set the ID for the RTP session.
+      */
+    void SetSessionID(unsigned id);
+
     /**Get the canonical name for the RTP session.
       */
     PString GetCanonicalName() const;
@@ -747,6 +749,10 @@ class RTP_Session : public PObject
       */
     PBoolean DecrementReference() { return --referenceCount == 0; }
 
+	/**Get Reference Count
+	  */
+	unsigned GetReferenceCount() const { return referenceCount; }
+
     /**Indicate if will ignore all but first received SSRC value.
       */
     PBoolean WillIgnoreOtherSources() const { return ignoreOtherSources; }
@@ -911,7 +917,7 @@ class RTP_Session : public PObject
     unsigned           referenceCount;
     RTP_UserData     * userData;
 
-#ifndef NO_H323_AUDIO_CODECS
+#ifdef H323_AUDIO_CODECS
     RTP_JitterBuffer * jitter;
 #endif
 
@@ -966,12 +972,70 @@ class RTP_Session : public PObject
     PMutex reportMutex;
     PTimer reportTimer;
 
+    // Sync Information
+    PBoolean avSyncData;
+    SenderReport  rtpSync;
+
 #ifdef H323_RTP_AGGREGATE
     PHandleAggregator * aggregator;
 #endif
 };
 
 
+/**This class is the base for user data that may be attached to the RTP_session
+   allowing callbacks for statistics and progress monitoring to be passed to an
+   arbitrary object that an RTP consumer may require.
+  */
+class RTP_UserData : public PObject
+{
+  PCLASSINFO(RTP_UserData, PObject);
+
+  public:
+    /**Callback from the RTP session for transmit statistics monitoring.
+       This is called every RTP_Session::txStatisticsInterval packets on the
+       transmitter indicating that the statistics have been updated.
+
+       The default behaviour does nothing.
+      */
+    virtual void OnTxStatistics(
+      const RTP_Session & session   ///<  Session with statistics
+    ) const;
+
+    /**Callback from the RTP session for receive statistics monitoring.
+       This is called every RTP_Session::receiverReportInterval packets on the
+       receiver indicating that the statistics have been updated.
+
+       The default behaviour does nothing.
+      */
+    virtual void OnRxStatistics(
+      const RTP_Session & session   ///<  Session with statistics
+    ) const;
+
+    /**Callback from the RTP session for statistics monitoring.
+       This is called at the end of a call to indicating 
+	   that the statistics of the call.
+
+       The default behaviour does nothing.
+      */
+    virtual void OnFinalStatistics(
+      const RTP_Session & session   ///<  Session with statistics
+    ) const;
+
+    /**Callback from the RTP session for statistics monitoring.
+       This is called when a RTPSenderReport is received
+
+       The default behaviour does nothing.
+      */
+    virtual void OnRxSenderReport(
+        unsigned sessionID,
+        const RTP_Session::SenderReport & send,
+        const RTP_Session::ReceiverReportArray & recv
+        ) const;
+
+};
+
+
+
 /**This class is for encpsulating the IETF Real Time Protocol interface.
  */
 class RTP_SessionManager : public PObject
@@ -1023,6 +1087,13 @@ class RTP_SessionManager : public PObject
       unsigned sessionID    ///<  Session ID to release.
     );
 
+    /**Move the session. 
+     */
+    void MoveSession(
+      unsigned oldSessionID,    ///<  Session ID from.
+      unsigned newSessionID     ///<  Session ID to.
+    );
+
     /**Get a session for the specified ID.
        Unlike UseSession, this does not increment the usage count on the
        session so may be used to just gain a pointer to an RTP session.
@@ -1069,7 +1140,7 @@ class RTP_SessionManager : public PObject
 
 
   protected:
-    PDICTIONARY(SessionDict, POrdinalKey, RTP_Session);
+    H323DICTIONARY(SessionDict, POrdinalKey, RTP_Session);
     SessionDict sessions;
     PMutex      mutex;
     PINDEX      enumerationIndex;
@@ -1110,6 +1181,11 @@ class RTP_UDP : public RTP_Session
       */
     virtual PBoolean ReadData(RTP_DataFrame & frame, PBoolean loop);
 
+    /**Read a data frame from the RTP channel that did not orginate
+       from the UDPSocket
+      */
+    virtual PBoolean PseudoRead(int & selectStatus);
+
     /**Write a data frame from the RTP channel.
       */
     virtual PBoolean WriteData(RTP_DataFrame & frame);
@@ -1139,7 +1215,7 @@ class RTP_UDP : public RTP_Session
       */
     virtual void EnableGQoS(PBoolean success = TRUE);
 
-#if P_HAS_QOS
+#if P_QOS
      /** Get the QOS settings
        */
       PQoS & GetQOS();
@@ -1223,6 +1299,10 @@ class RTP_UDP : public RTP_Session
     void ApplyQOS(
       const PIPSocket::Address & addr
     );
+
+    /**Whether the remote has been detected as being behind NAT.
+      */
+    PBoolean IsRemoteNAT()  { return remoteIsNAT; }
   //@}
 
     int GetDataSocketHandle() const
