@@ -27,6 +27,11 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: transports.h,v $
+ * Revision 1.3  2011/01/12 13:15:04  shorne
+ * Fix for H.225 Channel keep-alive
+ * Pass the tread pointer to HandleFirstSignallingChannel to avoid the possibility of spawning an external thread
+ * Fix Bug in Gatekeeper discovery if UDP channel could not be created
+ *
  * Revision 1.2  2008/05/23 11:20:14  willamowius
  * switch BOOL to PBoolean to be able to compile with Ptlib 2.2.x
  *
@@ -601,7 +606,7 @@ class H323Transport : public PIndirectChannel
     /**Wait for first PDU and find/create connection object.
        If returns FALSE, then the transport is deleted by the calling thread.
       */
-    PBoolean HandleFirstSignallingChannelPDU();
+    PBoolean HandleFirstSignallingChannelPDU(PThread * thread);
   //@}
 
   /**@name Control Channel */
