@@ -26,8 +26,8 @@
  */
 
 #define MAJOR_VERSION 1
-#define MINOR_VERSION 21
-#define BUILD_TYPE    BetaCode
+#define MINOR_VERSION 23
+#define BUILD_TYPE    ReleaseCode
 #define BUILD_NUMBER 0
 
 
